/// <reference types="node" />
import Promise from "bluebird";
import { SocketConnectOpts } from "net";
import { EventType, GsmListObject, GsmState, NetProtocol, PowerDisplay, PowerStatus, RedirObject, ScreenRecordOptions, SnapshotObject } from ".";
import { Ev_AbsCode, Ev_KeyCode, Ev_RelCode, Ev_SwCode } from "./emulatorcode";
export default class EmulatorClient {
    private connectOpt;
    private token;
    private parser;
    constructor(token: string, options: SocketConnectOpts);
    static readTokenSync(): string;
    static readToken(cb?: (err: Error, value: string) => void): Promise<string>;
    static listEmulators(cb?: (err: Error, value: number[]) => void): Promise<number[]>;
    static map<R>(mapper: (client: EmulatorClient) => R, token: string): Promise<void>;
    private connection;
    write(cmd: string, cb?: (err: Error, value: string) => void): Promise<string>;
    ping(): Promise<boolean>;
    automationRecord(name: string, cwd?: string): Promise<void>;
    automationStopRecord(): Promise<void>;
    automationPlay(name: string, cwd?: string): Promise<void>;
    automationStopPlay(): Promise<void>;
    powerDisplay(): Promise<PowerDisplay>;
    powerAc(status: "on" | "off"): Promise<void>;
    powerStatus(status: PowerStatus): Promise<void>;
    powerPresent(state: boolean): Promise<void>;
    powerHealth(state: "unknown" | "good" | "overheat" | "dead" | "overvoltage" | "failure"): Promise<void>;
    powerCapacity(capacity: number): Promise<void>;
    redirAdd(protocol: NetProtocol, hostPort: number, guestPort: number): Promise<void>;
    redirDel(protocol: NetProtocol, hostPort: number): Promise<void>;
    redirList(): Promise<RedirObject[]>;
    sms(phoneNr: number | string, message: string): Promise<void>;
    eventCodes(type: EventType): Promise<string[]>;
    eventSend(type: "EV_KEY", code: Ev_KeyCode, value: 0 | 1 | string): Promise<void>;
    eventSend(type: "EV_REL", code: Ev_RelCode, value: 0 | 1 | string): Promise<void>;
    eventSend(type: "EV_ABS", code: Ev_AbsCode, value: 0 | 1 | string): Promise<void>;
    eventSend(type: "EV_SW", code: Ev_SwCode, value: 0 | 1 | string): Promise<void>;
    eventSend(type: EventType, code: string | number, value: 0 | 1 | string): Promise<void>;
    eventSend(type: string | number, code: string | number, value: 0 | 1 | string): Promise<void>;
    eventMouse(x: number, y: number, device?: number, bntState?: number): Promise<void>;
    sensorStatus(): Promise<Record<string, "enabled" | "disabled">>;
    sensorGet(name: string): Promise<number[]>;
    sensorSet(name: string, valueA: number, valueB?: number, valueC?: number): Promise<void>;
    physicsRecordGt(name: string, cwd?: string): Promise<void>;
    physicsStop(): Promise<void>;
    geoNmea(sentence: string, ...params: string[]): Promise<void>;
    geoFix(longitude: number, latitude: number, altitude?: number, satellites?: number, velocity?: number): Promise<void>;
    geoGnss(...values: string[]): Promise<void>;
    gsmList(): Promise<GsmListObject[]>;
    gsmCall(phoneNr: string | number): Promise<void>;
    gsmBusy(phoneNr: string | number): Promise<void>;
    gsmHold(phoneNr: string | number): Promise<void>;
    gsmAccept(phoneNr: string | number): Promise<void>;
    gsmCancel(phoneNr: string | number): Promise<void>;
    gsmData(state: GsmState): Promise<void>;
    gsmMeter(state: "on" | "off"): Promise<void>;
    gsmVoice(state: GsmState): Promise<void>;
    gsmStatus(): Promise<Record<string, GsmState>>;
    gsmSignal(rssi: number, ber?: number): Promise<void>;
    gsmSignalProfile(strength: 0 | 1 | 2 | 3 | 4): Promise<void>;
    cdmaSsource(source: "nv" | "ruim"): Promise<void>;
    cdmaPrlVersion(version: string | number): Promise<void>;
    crash(): Promise<void>;
    crashOnExit(): Promise<void>;
    kill(): Promise<void>;
    restart(): Promise<void>;
    networkStatus(): Promise<Record<string, string>>;
    networkSpeed(up: number, down: number): Promise<void>;
    networkSpeed(speed: "gsm" | "hscsd" | "gprs" | "edge" | "umts" | "hsdpa" | "lte" | "evdo" | "full"): Promise<void>;
    networkSpeed(speed: number): Promise<void>;
    networkDelay(min: number, max: number): Promise<void>;
    networkDelay(delay: "gprs" | "edge" | "umts" | "none"): Promise<void>;
    networkDelay(delay: number): Promise<void>;
    networkCaptureStart(name: string, cwd?: string): Promise<void>;
    networkCaptureStop(): Promise<void>;
    avdStop(): Promise<void>;
    avdStart(): Promise<void>;
    avdStatus(): Promise<"running" | "stopped">;
    avdHeartbeat(): Promise<number>;
    avdRewindaudio(): Promise<void>;
    avdName(): Promise<string>;
    avdSnapshotList(): Promise<SnapshotObject[]>;
    avdSnapshotSave(name: string): Promise<void>;
    avdSnapshotLoad(name: string): Promise<void>;
    avdSnapshotDelete(name: string): Promise<void>;
    avdSnapshotRemap(autoSave: 0 | 1): Promise<void>;
    fingerTouch(id: number): Promise<void>;
    fingerRemove(): Promise<void>;
    debug(...tags: string[]): Promise<void>;
    rotate(): Promise<void>;
    screenrecordStart(name: string, options?: ScreenRecordOptions & {
        cwd?: string;
    }): Promise<void>;
    screenrecordStop(): Promise<void>;
    screenrecordScreenshot(dirName: string, displayId?: number): Promise<void>;
    screenrecordWebrtcStart(fps?: number): Promise<string>;
    screenrecordWebrtcStop(): Promise<void>;
    fold(): Promise<void>;
    unfold(): Promise<void>;
    multidisplayAdd(id: number, width: number, height: number, dpi: number, flag?: number): Promise<void>;
    multidisplayDel(id: number): Promise<void>;
    grpc(port: number): Promise<void>;
    startExtendedWindow(): Promise<void>;
    quitExtendedWindow(): Promise<void>;
    setUiTheme(theme: "light" | "dark"): Promise<void>;
    iceboxTrack(pid: number, maxSnapshots?: number): Promise<void>;
}
