"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var bluebird_1 = __importDefault(require("bluebird"));
var fs_1 = __importDefault(require("fs"));
var net_1 = require("net");
var path_1 = __importDefault(require("path"));
var user_home_1 = __importDefault(require("user-home"));
var _1 = require(".");
var command_1 = __importDefault(require("./command"));
var avdheartbeat_1 = __importDefault(require("./commands/avdheartbeat"));
var avdname_1 = __importDefault(require("./commands/avdname"));
var avdsnapshotlist_1 = __importDefault(require("./commands/avdsnapshotlist"));
var avdstatus_1 = __importDefault(require("./commands/avdstatus"));
var eventcodes_1 = __importDefault(require("./commands/eventcodes"));
var gsmlist_1 = __importDefault(require("./commands/gsmlist"));
var gsmstatus_1 = __importDefault(require("./commands/gsmstatus"));
var networkstatus_1 = __importDefault(require("./commands/networkstatus"));
var pingcommand_1 = __importDefault(require("./commands/pingcommand"));
var powedisplay_1 = __importDefault(require("./commands/powedisplay"));
var redirlist_1 = __importDefault(require("./commands/redirlist"));
var screenrecordwebrtc_1 = __importDefault(require("./commands/screenrecordwebrtc"));
var sensorget_1 = __importDefault(require("./commands/sensorget"));
var sensorstatus_1 = __importDefault(require("./commands/sensorstatus"));
var connection_1 = __importDefault(require("./connection"));
var parser_1 = __importDefault(require("./parser"));
var voidcommand_1 = __importDefault(require("./voidcommand"));
var voidiqueuecommand_1 = __importDefault(require("./voidiqueuecommand"));
var EmulatorClient = (function () {
    function EmulatorClient(token, options) {
        this.token = token;
        this.connectOpt = options;
        this.parser = new parser_1.default();
    }
    EmulatorClient.readTokenSync = function () {
        return fs_1.default
            .readFileSync(path_1.default.join(user_home_1.default, ".emulator_console_auth_token"))
            .toString();
    };
    EmulatorClient.readToken = function (cb) {
        return new bluebird_1.default(function (resolve, reject) {
            fs_1.default.readFile(path_1.default.join(user_home_1.default, ".emulator_console_auth_token"), function (err, data) {
                if (err)
                    return reject(err);
                else
                    return resolve(data.toString());
            });
        }).nodeify(cb);
    };
    EmulatorClient.listEmulators = function (cb) {
        return bluebird_1.default.map(_1.EmulatorPorts, function (port) {
            return new bluebird_1.default(function (resolve) {
                var socket = new net_1.Socket();
                socket.setTimeout(50, function () {
                    resolve();
                    socket.end();
                });
                socket.once("data", function (data) {
                    var dataStr = data.toString();
                    if (/OK/.test(dataStr.slice(dataStr.length - 4, dataStr.length - 2))) {
                        resolve(port);
                    }
                    else {
                        resolve();
                    }
                    socket.end();
                });
                socket.once("error", function () {
                    resolve();
                    socket.end();
                });
                socket.connect(port);
            });
        })
            .then(function (ports) {
            return ports.filter(function (port) { return port; });
        })
            .nodeify(cb);
    };
    EmulatorClient.map = function (mapper, token) {
        return EmulatorClient.listEmulators().then(function (ports) {
            bluebird_1.default.map(ports, function (port) {
                return mapper(new EmulatorClient(token, { port: port }));
            });
        });
    };
    EmulatorClient.prototype.connection = function () {
        var _this = this;
        return new bluebird_1.default(function (resolve, reject) {
            var stream = new connection_1.default(_this.token, _this.parser, _this.connectOpt);
            stream.on("auth", function () {
                resolve(stream);
            });
            stream.on("error", reject);
        });
    };
    EmulatorClient.prototype.write = function (cmd, cb) {
        var _this = this;
        return this.connection()
            .then(function (conn) {
            return new command_1.default(conn, _this.parser)
                .setTimeout(100)
                .execute(cmd);
        })
            .nodeify(cb);
    };
    EmulatorClient.prototype.ping = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new pingcommand_1.default(conn, _this.parser).execute();
        });
    };
    EmulatorClient.prototype.automationRecord = function (name, cwd) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("automation record ".concat(cwd ? path_1.default.join(cwd, name) : name));
        });
    };
    EmulatorClient.prototype.automationStopRecord = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("automation stop-record");
        });
    };
    EmulatorClient.prototype.automationPlay = function (name, cwd) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("automation play ".concat(cwd ? path_1.default.join(cwd, name) : name));
        });
    };
    EmulatorClient.prototype.automationStopPlay = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("automation stop-play");
        });
    };
    EmulatorClient.prototype.powerDisplay = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new powedisplay_1.default(conn, _this.parser).execute();
        });
    };
    EmulatorClient.prototype.powerAc = function (status) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("power ac ".concat(status));
        });
    };
    EmulatorClient.prototype.powerStatus = function (status) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("power status ".concat(status));
        });
    };
    EmulatorClient.prototype.powerPresent = function (state) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("power present ".concat(state));
        });
    };
    EmulatorClient.prototype.powerHealth = function (state) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("power health ".concat(state));
        });
    };
    EmulatorClient.prototype.powerCapacity = function (capacity) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("power capacity ".concat(capacity));
        });
    };
    EmulatorClient.prototype.redirAdd = function (protocol, hostPort, guestPort) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("redir add ".concat(protocol, ":").concat(hostPort, ":").concat(guestPort));
        });
    };
    EmulatorClient.prototype.redirDel = function (protocol, hostPort) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("redir del ".concat(protocol, ":").concat(hostPort));
        });
    };
    EmulatorClient.prototype.redirList = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new redirlist_1.default(conn, _this.parser).execute();
        });
    };
    EmulatorClient.prototype.sms = function (phoneNr, message) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("sms send ".concat(phoneNr, " ").concat(message));
        });
    };
    EmulatorClient.prototype.eventCodes = function (type) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new eventcodes_1.default(conn, _this.parser).execute(type);
        });
    };
    EmulatorClient.prototype.eventSend = function (type, code, value) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("event send ".concat(type, ":").concat(code, ":").concat(value));
        });
    };
    EmulatorClient.prototype.eventMouse = function (x, y, device, bntState) {
        var _this = this;
        if (device === void 0) { device = 0; }
        if (bntState === void 0) { bntState = 1; }
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("event mouse ".concat(x, " ").concat(y, " ").concat(device, " ").concat(bntState));
        });
    };
    EmulatorClient.prototype.sensorStatus = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new sensorstatus_1.default(conn, _this.parser).execute();
        });
    };
    EmulatorClient.prototype.sensorGet = function (name) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new sensorget_1.default(conn, _this.parser).execute(name);
        });
    };
    EmulatorClient.prototype.sensorSet = function (name, valueA, valueB, valueC) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidiqueuecommand_1.default(conn, _this.parser)
                .addArg(valueB, ":")
                .addArg(valueC, ":")
                .execute("sensor set ".concat(name, " ").concat(valueA));
        });
    };
    EmulatorClient.prototype.physicsRecordGt = function (name, cwd) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("physics record-gt ".concat(cwd ? path_1.default.join(cwd, name) : name));
        });
    };
    EmulatorClient.prototype.physicsStop = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("physics stop");
        });
    };
    EmulatorClient.prototype.geoNmea = function (sentence) {
        var _this = this;
        var params = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            params[_i - 1] = arguments[_i];
        }
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("geo nmea ".concat(sentence, ", ").concat(params.join(",")));
        });
    };
    EmulatorClient.prototype.geoFix = function (longitude, latitude, altitude, satellites, velocity) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidiqueuecommand_1.default(conn, _this.parser)
                .addArg(altitude, " ")
                .addArg(satellites, " ")
                .addArg(velocity, " ")
                .execute("geo fix ".concat(longitude, " ").concat(latitude));
        });
    };
    EmulatorClient.prototype.geoGnss = function () {
        var _this = this;
        var values = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            values[_i] = arguments[_i];
        }
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("geo gnss ".concat(values.join(",")));
        });
    };
    EmulatorClient.prototype.gsmList = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new gsmlist_1.default(conn, _this.parser).execute();
        });
    };
    EmulatorClient.prototype.gsmCall = function (phoneNr) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("gsm call ".concat(phoneNr));
        });
    };
    EmulatorClient.prototype.gsmBusy = function (phoneNr) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("gsm busy ".concat(phoneNr));
        });
    };
    EmulatorClient.prototype.gsmHold = function (phoneNr) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("gsm hold ".concat(phoneNr));
        });
    };
    EmulatorClient.prototype.gsmAccept = function (phoneNr) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("gsm accept ".concat(phoneNr));
        });
    };
    EmulatorClient.prototype.gsmCancel = function (phoneNr) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("gsm cancel ".concat(phoneNr));
        });
    };
    EmulatorClient.prototype.gsmData = function (state) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("gsm data ".concat(state));
        });
    };
    EmulatorClient.prototype.gsmMeter = function (state) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("gsm meter ".concat(state));
        });
    };
    EmulatorClient.prototype.gsmVoice = function (state) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("gsm voice ".concat(state));
        });
    };
    EmulatorClient.prototype.gsmStatus = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new gsmstatus_1.default(conn, _this.parser).execute();
        });
    };
    EmulatorClient.prototype.gsmSignal = function (rssi, ber) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidiqueuecommand_1.default(conn, _this.parser)
                .addArg(ber, " ")
                .execute("gsm signal ".concat(rssi));
        });
    };
    EmulatorClient.prototype.gsmSignalProfile = function (strength) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("gsm signal-profile ".concat(strength));
        });
    };
    EmulatorClient.prototype.cdmaSsource = function (source) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("cdma ssource ".concat(source));
        });
    };
    EmulatorClient.prototype.cdmaPrlVersion = function (version) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("cdma prl_version ".concat(version));
        });
    };
    EmulatorClient.prototype.crash = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("crash");
        });
    };
    EmulatorClient.prototype.crashOnExit = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("crash-on-exit");
        });
    };
    EmulatorClient.prototype.kill = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("kill");
        });
    };
    EmulatorClient.prototype.restart = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("restart");
        });
    };
    EmulatorClient.prototype.networkStatus = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new networkstatus_1.default(conn, _this.parser).execute();
        });
    };
    EmulatorClient.prototype.networkSpeed = function (speed, param) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidiqueuecommand_1.default(conn, _this.parser)
                .addArg(param, ":")
                .execute("network speed ".concat(speed));
        });
    };
    EmulatorClient.prototype.networkDelay = function (delay, param) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidiqueuecommand_1.default(conn, _this.parser)
                .addArg(param, ":")
                .execute("network delay ".concat(delay));
        });
    };
    EmulatorClient.prototype.networkCaptureStart = function (name, cwd) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("network capture start ".concat(cwd ? path_1.default.join(cwd, name) : name));
        });
    };
    EmulatorClient.prototype.networkCaptureStop = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("network capture stop");
        });
    };
    EmulatorClient.prototype.avdStop = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("avd stop");
        });
    };
    EmulatorClient.prototype.avdStart = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("avd start");
        });
    };
    EmulatorClient.prototype.avdStatus = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new avdstatus_1.default(conn, _this.parser).execute();
        });
    };
    EmulatorClient.prototype.avdHeartbeat = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new avdheartbeat_1.default(conn, _this.parser).execute();
        });
    };
    EmulatorClient.prototype.avdRewindaudio = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("avd rewindaudio");
        });
    };
    EmulatorClient.prototype.avdName = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new avdname_1.default(conn, _this.parser).execute();
        });
    };
    EmulatorClient.prototype.avdSnapshotList = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new avdsnapshotlist_1.default(conn, _this.parser).execute();
        });
    };
    EmulatorClient.prototype.avdSnapshotSave = function (name) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("avd snapshot save ".concat(name));
        });
    };
    EmulatorClient.prototype.avdSnapshotLoad = function (name) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("avd snapshot load ".concat(name));
        });
    };
    EmulatorClient.prototype.avdSnapshotDelete = function (name) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("avd snapshot delete ".concat(name));
        });
    };
    EmulatorClient.prototype.avdSnapshotRemap = function (autoSave) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("avd snapshot remap ".concat(autoSave));
        });
    };
    EmulatorClient.prototype.fingerTouch = function (id) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("finger touch ".concat(id));
        });
    };
    EmulatorClient.prototype.fingerRemove = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("finger remove");
        });
    };
    EmulatorClient.prototype.debug = function () {
        var _this = this;
        var tags = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            tags[_i] = arguments[_i];
        }
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("debug ".concat(tags.join(",")));
        });
    };
    EmulatorClient.prototype.rotate = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("rotate");
        });
    };
    EmulatorClient.prototype.screenrecordStart = function (name, options) {
        var _this = this;
        options = options || {};
        var cwd = options.cwd, height = options.height, width = options.width, bitRate = options.bitRate, timeLimit = options.timeLimit, fsp = options.fsp;
        return this.connection().then(function (conn) {
            return new voidiqueuecommand_1.default(conn, _this.parser)
                .setTimeout(100)
                .addArg(height !== undefined && width !== undefined
                ? "--size ".concat(width, "x").concat(height)
                : undefined, " ")
                .addArg(bitRate !== undefined ? "--bit-rate ".concat(bitRate) : undefined, " ")
                .addArg(timeLimit !== undefined ? "--time-limit ".concat(timeLimit) : undefined, " ")
                .addArg(fsp !== undefined ? "--fps ".concat(fsp) : undefined, " ")
                .addArg("".concat(cwd ? path_1.default.join(cwd, name) : name, ".webm"), " ")
                .execute("screenrecord start");
        });
    };
    EmulatorClient.prototype.screenrecordStop = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("screenrecord stop");
        });
    };
    EmulatorClient.prototype.screenrecordScreenshot = function (dirName, displayId) {
        var _this = this;
        if (displayId === void 0) { displayId = 0; }
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("screenrecord screenshot --display ".concat(displayId, " ").concat(dirName));
        });
    };
    EmulatorClient.prototype.screenrecordWebrtcStart = function (fps) {
        var _this = this;
        if (fps === void 0) { fps = 60; }
        return this.connection().then(function (conn) {
            return new screenrecordwebrtc_1.default(conn, _this.parser).execute(fps);
        });
    };
    EmulatorClient.prototype.screenrecordWebrtcStop = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("screenrecord webrtc stop");
        });
    };
    EmulatorClient.prototype.fold = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).setTimeout(100).execute("fold");
        });
    };
    EmulatorClient.prototype.unfold = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser)
                .setTimeout(100)
                .execute("unfold");
        });
    };
    EmulatorClient.prototype.multidisplayAdd = function (id, width, height, dpi, flag) {
        var _this = this;
        if (flag === void 0) { flag = 0; }
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("multidisplay add ".concat(id, " ").concat(width, " ").concat(height, " ").concat(dpi, " ").concat(flag));
        });
    };
    EmulatorClient.prototype.multidisplayDel = function (id) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("multidisplay del ".concat(id));
        });
    };
    EmulatorClient.prototype.grpc = function (port) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("grpc ".concat(port));
        });
    };
    EmulatorClient.prototype.startExtendedWindow = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("startExtendedWindow");
        });
    };
    EmulatorClient.prototype.quitExtendedWindow = function () {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("quitExtendedWindow");
        });
    };
    EmulatorClient.prototype.setUiTheme = function (theme) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidcommand_1.default(conn, _this.parser).execute("setUiTheme ".concat(theme));
        });
    };
    EmulatorClient.prototype.iceboxTrack = function (pid, maxSnapshots) {
        var _this = this;
        return this.connection().then(function (conn) {
            return new voidiqueuecommand_1.default(conn, _this.parser)
                .addArg(maxSnapshots, " ")
                .execute("icebox track ".concat(pid));
        });
    };
    return EmulatorClient;
}());
exports.default = EmulatorClient;
